
# Slot: object




URI: [biolink:thing_to_disease_or_phenotypic_feature_association_object](https://w3id.org/biolink/vocab/thing_to_disease_or_phenotypic_feature_association_object)

## Domain and Range

[ThingToDiseaseOrPhenotypicFeatureAssociation](ThingToDiseaseOrPhenotypicFeatureAssociation.md) ->  <sub>REQ</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [ThingToDiseaseOrPhenotypicFeatureAssociation](ThingToDiseaseOrPhenotypicFeatureAssociation.md)
